==> jangaroo-sdk-0.9.3.zip: joo/classes/flash/globalization/NationalDigitsType.js <==
joo.classLoader.prepare("package flash.globalization",/* {*/


/**
 * The NationalDigitsType class enumerates constants that indicate digit sets used by the NumberFormatter class. The value of each constant represents the Unicode value for the zero digit in the specified decimal digit set.
 */
"public final class NationalDigitsType",1,function($$private){;return[ 
  /**
   * Represents the Unicode value for the zero digit of the Arabic-Indic digit set.
   */
  "public static const",{ ARABIC_INDIC/*:uint*/ : 0x0660},
  /**
   * Represents the Unicode value for the zero digit of the Balinese digit set.
   */
  "public static const",{ BALINESE/*:uint*/ : 0x1B50},
  /**
   * Represents the Unicode value for the zero digit of the Bengali digit set.
   */
  "public static const",{ BENGALI/*:uint*/ : 0x09E6},
  /**
   * Represents the Unicode value for the zero digit of the Cham digit set.
   */
  "public static const",{ CHAM/*:uint*/ : 0xAA50},
  /**
   * Represents the Unicode value for the zero digit of the Devanagari digit set.
   */
  "public static const",{ DEVANAGARI/*:uint*/ : 0x0966},
  /**
   * Represents the Unicode value for the zero digit of the Latin-1 (European) digit set.
   */
  "public static const",{ EUROPEAN/*:uint*/ : 0x0030},
  /**
   * Represents the Unicode value for the zero digit of the Extended Arabic-Indic digit set.
   */
  "public static const",{ EXTENDED_ARABIC_INDIC/*:uint*/ : 0x06F0},
  /**
   * Represents the Unicode value for the zero digit of the Fullwidth digit set.
   */
  "public static const",{ FULL_WIDTH/*:uint*/ : 0xFF10},
  /**
   * Represents the Unicode value for the zero digit of the Gujarati digit set.
   */
  "public static const",{ GUJARATI/*:uint*/ : 0x0AE6},
  /**
   * Represents the Unicode value for the zero digit of the Gurmukhi digit set.
   */
  "public static const",{ GURMUKHI/*:uint*/ : 0x0A66},
  /**
   * Represents the Unicode value for the zero digit of the Kannada digit set.
   */
  "public static const",{ KANNADA/*:uint*/ : 0x0CE6},
  /**
   * Represents the Unicode value for the zero digit of the Kayah Li digit set.
   */
  "public static const",{ KAYAH_LI/*:uint*/ : 0xA900},
  /**
   * Represents the Unicode value for the zero digit of the Khmer digit set.
   */
  "public static const",{ KHMER/*:uint*/ : 0x17E0},
  /**
   * Represents the Unicode value for the zero digit of the Lao digit set.
   */
  "public static const",{ LAO/*:uint*/ : 0x0ED0},
  /**
   * Represents the Unicode value for the zero digit of the Lepcha digit set.
   */
  "public static const",{ LEPCHA/*:uint*/ : 0x1C40},
  /**
   * Represents the Unicode value for the zero digit of the Limbu digit set.
   */
  "public static const",{ LIMBU/*:uint*/ : 0x1946},
  /**
   * Represents the Unicode value for the zero digit of the Malayalam digit set.
   */
  "public static const",{ MALAYALAM/*:uint*/ : 0x0D66},
  /**
   * Represents the Unicode value for the zero digit of the Mongolian digit set.
   */
  "public static const",{ MONGOLIAN/*:uint*/ : 0x1810},
  /**
   * Represents the Unicode value for the zero digit of the Myanmar digit set.
   */
  "public static const",{ MYANMAR/*:uint*/ : 0x1040},
  /**
   * Represents the Unicode value for the zero digit of the Myanmar Shan digit set.
   */
  "public static const",{ MYANMAR_SHAN/*:uint*/ : 0x1090},
  /**
   * Represents the Unicode value for the zero digit of the New Tai Lue digit set.
   */
  "public static const",{ NEW_TAI_LUE/*:uint*/ : 0x19D0},
  /**
   * Represents the Unicode value for the zero digit of the Nko digit set.
   */
  "public static const",{ NKO/*:uint*/ : 0x07C0},
  /**
   * Represents the Unicode value for the zero digit of the Ol Chiki digit set.
   */
  "public static const",{ OL_CHIKI/*:uint*/ : 0x1C50},
  /**
   * Represents the Unicode value for the zero digit of the Oriya digit set.
   */
  "public static const",{ ORIYA/*:uint*/ : 0x0B66},
  /**
   * Represents the Unicode value for the zero digit of the Osmanya digit set.
   */
  "public static const",{ OSMANYA/*:uint*/ : 0x104A0},
  /**
   * Represents the Unicode value for the zero digit of the Saurashtra digit set.
   */
  "public static const",{ SAURASHTRA/*:uint*/ : 0xA8D0},
  /**
   * Represents the Unicode value for the zero digit of the Sundanese digit set.
   */
  "public static const",{ SUNDANESE/*:uint*/ : 0x1BB0},
  /**
   * Represents the Unicode value for the zero digit of the Tamil digit set.
   */
  "public static const",{ TAMIL/*:uint*/ : 0x0BE6},
  /**
   * Represents the Unicode value for the zero digit of the Telugu digit set.
   */
  "public static const",{ TELUGU/*:uint*/ : 0x0C66},
  /**
   * Represents the Unicode value for the zero digit of the Thai digit set.
   */
  "public static const",{ THAI/*:uint*/ : 0x0E50},
  /**
   * Represents the Unicode value for the zero digit of the Tibetan digit set.
   */
  "public static const",{ TIBETAN/*:uint*/ : 0x0F20},
  /**
   * Represents the Unicode value for the zero digit of the Vai digit set.
   */
  "public static const",{ VAI/*:uint*/ : 0xA620},
];},[],[], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flash/globalization/NationalDigitsType.js <==
joo.classLoader.prepare("package flash.globalization",/* {*/


/**
 * The NationalDigitsType class enumerates constants that indicate digit sets used by the NumberFormatter class. The value of each constant represents the Unicode value for the zero digit in the specified decimal digit set.
 */
"public final class NationalDigitsType",1,function($$private){return[ 
  /**
   * Represents the Unicode value for the zero digit of the Arabic-Indic digit set.
   */
  "public static const",{ ARABIC_INDIC/*:uint*/ : 0x0660},
  /**
   * Represents the Unicode value for the zero digit of the Balinese digit set.
   */
  "public static const",{ BALINESE/*:uint*/ : 0x1B50},
  /**
   * Represents the Unicode value for the zero digit of the Bengali digit set.
   */
  "public static const",{ BENGALI/*:uint*/ : 0x09E6},
  /**
   * Represents the Unicode value for the zero digit of the Cham digit set.
   */
  "public static const",{ CHAM/*:uint*/ : 0xAA50},
  /**
   * Represents the Unicode value for the zero digit of the Devanagari digit set.
   */
  "public static const",{ DEVANAGARI/*:uint*/ : 0x0966},
  /**
   * Represents the Unicode value for the zero digit of the Latin-1 (European) digit set.
   */
  "public static const",{ EUROPEAN/*:uint*/ : 0x0030},
  /**
   * Represents the Unicode value for the zero digit of the Extended Arabic-Indic digit set.
   */
  "public static const",{ EXTENDED_ARABIC_INDIC/*:uint*/ : 0x06F0},
  /**
   * Represents the Unicode value for the zero digit of the Fullwidth digit set.
   */
  "public static const",{ FULL_WIDTH/*:uint*/ : 0xFF10},
  /**
   * Represents the Unicode value for the zero digit of the Gujarati digit set.
   */
  "public static const",{ GUJARATI/*:uint*/ : 0x0AE6},
  /**
   * Represents the Unicode value for the zero digit of the Gurmukhi digit set.
   */
  "public static const",{ GURMUKHI/*:uint*/ : 0x0A66},
  /**
   * Represents the Unicode value for the zero digit of the Kannada digit set.
   */
  "public static const",{ KANNADA/*:uint*/ : 0x0CE6},
  /**
   * Represents the Unicode value for the zero digit of the Kayah Li digit set.
   */
  "public static const",{ KAYAH_LI/*:uint*/ : 0xA900},
  /**
   * Represents the Unicode value for the zero digit of the Khmer digit set.
   */
  "public static const",{ KHMER/*:uint*/ : 0x17E0},
  /**
   * Represents the Unicode value for the zero digit of the Lao digit set.
   */
  "public static const",{ LAO/*:uint*/ : 0x0ED0},
  /**
   * Represents the Unicode value for the zero digit of the Lepcha digit set.
   */
  "public static const",{ LEPCHA/*:uint*/ : 0x1C40},
  /**
   * Represents the Unicode value for the zero digit of the Limbu digit set.
   */
  "public static const",{ LIMBU/*:uint*/ : 0x1946},
  /**
   * Represents the Unicode value for the zero digit of the Malayalam digit set.
   */
  "public static const",{ MALAYALAM/*:uint*/ : 0x0D66},
  /**
   * Represents the Unicode value for the zero digit of the Mongolian digit set.
   */
  "public static const",{ MONGOLIAN/*:uint*/ : 0x1810},
  /**
   * Represents the Unicode value for the zero digit of the Myanmar digit set.
   */
  "public static const",{ MYANMAR/*:uint*/ : 0x1040},
  /**
   * Represents the Unicode value for the zero digit of the Myanmar Shan digit set.
   */
  "public static const",{ MYANMAR_SHAN/*:uint*/ : 0x1090},
  /**
   * Represents the Unicode value for the zero digit of the New Tai Lue digit set.
   */
  "public static const",{ NEW_TAI_LUE/*:uint*/ : 0x19D0},
  /**
   * Represents the Unicode value for the zero digit of the Nko digit set.
   */
  "public static const",{ NKO/*:uint*/ : 0x07C0},
  /**
   * Represents the Unicode value for the zero digit of the Ol Chiki digit set.
   */
  "public static const",{ OL_CHIKI/*:uint*/ : 0x1C50},
  /**
   * Represents the Unicode value for the zero digit of the Oriya digit set.
   */
  "public static const",{ ORIYA/*:uint*/ : 0x0B66},
  /**
   * Represents the Unicode value for the zero digit of the Osmanya digit set.
   */
  "public static const",{ OSMANYA/*:uint*/ : 0x104A0},
  /**
   * Represents the Unicode value for the zero digit of the Saurashtra digit set.
   */
  "public static const",{ SAURASHTRA/*:uint*/ : 0xA8D0},
  /**
   * Represents the Unicode value for the zero digit of the Sundanese digit set.
   */
  "public static const",{ SUNDANESE/*:uint*/ : 0x1BB0},
  /**
   * Represents the Unicode value for the zero digit of the Tamil digit set.
   */
  "public static const",{ TAMIL/*:uint*/ : 0x0BE6},
  /**
   * Represents the Unicode value for the zero digit of the Telugu digit set.
   */
  "public static const",{ TELUGU/*:uint*/ : 0x0C66},
  /**
   * Represents the Unicode value for the zero digit of the Thai digit set.
   */
  "public static const",{ THAI/*:uint*/ : 0x0E50},
  /**
   * Represents the Unicode value for the zero digit of the Tibetan digit set.
   */
  "public static const",{ TIBETAN/*:uint*/ : 0x0F20},
  /**
   * Represents the Unicode value for the zero digit of the Vai digit set.
   */
  "public static const",{ VAI/*:uint*/ : 0xA620},
undefined];},[],[], "0.8.0", "0.9.12"
);
